@@ -18,7 +18,7 @@ pub const RUN_AGAIN: RunAgain = true;
 pub const DONT_RUN_AGAIN: RunAgain = false;
 
 /// A `RuntimeError` is an error that occurred during the running of a Function's `Implementation`
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq)]
 pub enum RuntimeError {
     /// There was an error with the inputs to the `Implementation`
     InputError(String),
